contains_dynamic_find_syntax

Function contains_dynamic_find_syntax 

pub fn contains_dynamic_find_syntax(script: &str) -> bool
Returns whether a find command contains shell syntax that can change the literal option tokens after approval-time tokenization.