Module command_validation
vtcode_
safety
0.141.2
Module command_
validation
Module Items
Functions
In vtcode_
safety::
exec_
policy
vtcode_safety
::
exec_policy
Module
command_
validation
Functions

sanitize_
working_
dir
Normalize a working directory relative to the workspace root.
validate_
command
Validate whether a command is allowed to run under the execution policy.