pub async fn test_network_blocked(
policy: &SandboxPolicy,
cwd: &Path,
linux_launcher: Option<&LinuxSandboxLauncher>,
) -> Result<bool>Expand description
Test if network access is blocked under the given sandbox policy.
pub async fn test_network_blocked(
policy: &SandboxPolicy,
cwd: &Path,
linux_launcher: Option<&LinuxSandboxLauncher>,
) -> Result<bool>Test if network access is blocked under the given sandbox policy.