pub struct SensitivePath {
pub path: String,
pub block_read: bool,
pub block_write: bool,
}Expand description
Sensitive path entry for blocking access to credential locations.
Fields
path: StringPath pattern (supports ~ for home directory)
block_read: boolWhether to block read access (true by default)
block_write: boolWhether to block write access (true by default)
Implementations
Sourceimpl SensitivePath
impl SensitivePath
Sourcepub fn new(path: impl Into<String>) -> Self
pub fn new(path: impl Into<String>) -> Self
Create a new sensitive path entry that blocks both read and write.
Sourcepub fn write_only(path: impl Into<String>) -> Self
pub fn write_only(path: impl Into<String>) -> Self
Create a sensitive path entry that only blocks write access.
Sourcepub fn expand_path(&self) -> PathBuf
pub fn expand_path(&self) -> PathBuf
Expand ~ to the user’s home directory.